==> types_boto3_full-1.35.74-py3-none-any.whl: types_boto3_rekognition/paginator.py <==
"""
Type annotations for rekognition service client paginators.

[Open documentation](https://youtype.github.io/types_boto3_docs/types_boto3_rekognition/paginators/)

Usage::

    ```python
    from boto3.session import Session

    from types_boto3_rekognition.client import RekognitionClient
    from types_boto3_rekognition.paginator import (
        DescribeProjectVersionsPaginator,
        DescribeProjectsPaginator,
        ListCollectionsPaginator,
        ListDatasetEntriesPaginator,
        ListDatasetLabelsPaginator,
        ListFacesPaginator,
        ListProjectPoliciesPaginator,
        ListStreamProcessorsPaginator,
        ListUsersPaginator,
    )

    session = Session()
    client: RekognitionClient = session.client("rekognition")

    describe_project_versions_paginator: DescribeProjectVersionsPaginator = client.get_paginator("describe_project_versions")
    describe_projects_paginator: DescribeProjectsPaginator = client.get_paginator("describe_projects")
    list_collections_paginator: ListCollectionsPaginator = client.get_paginator("list_collections")
    list_dataset_entries_paginator: ListDatasetEntriesPaginator = client.get_paginator("list_dataset_entries")
    list_dataset_labels_paginator: ListDatasetLabelsPaginator = client.get_paginator("list_dataset_labels")
    list_faces_paginator: ListFacesPaginator = client.get_paginator("list_faces")
    list_project_policies_paginator: ListProjectPoliciesPaginator = client.get_paginator("list_project_policies")
    list_stream_processors_paginator: ListStreamProcessorsPaginator = client.get_paginator("list_stream_processors")
    list_users_paginator: ListUsersPaginator = client.get_paginator("list_users")
    ```

Copyright 2024 Vlad Emelianov
"""

import sys
from typing import Generic, Iterator, TypeVar

from botocore.paginate import PageIterator, Paginator

from .type_defs import (
    DescribeProjectsRequestDescribeProjectsPaginateTypeDef,
    DescribeProjectsResponseTypeDef,
    DescribeProjectVersionsRequestDescribeProjectVersionsPaginateTypeDef,
    DescribeProjectVersionsResponseTypeDef,
    ListCollectionsRequestListCollectionsPaginateTypeDef,
    ListCollectionsResponseTypeDef,
    ListDatasetEntriesRequestListDatasetEntriesPaginateTypeDef,
    ListDatasetEntriesResponseTypeDef,
    ListDatasetLabelsRequestListDatasetLabelsPaginateTypeDef,
    ListDatasetLabelsResponseTypeDef,
    ListFacesRequestListFacesPaginateTypeDef,
    ListFacesResponseTypeDef,
    ListProjectPoliciesRequestListProjectPoliciesPaginateTypeDef,
    ListProjectPoliciesResponseTypeDef,
    ListStreamProcessorsRequestListStreamProcessorsPaginateTypeDef,
    ListStreamProcessorsResponseTypeDef,
    ListUsersRequestListUsersPaginateTypeDef,
    ListUsersResponseTypeDef,
)

if sys.version_info >= (3, 12):
    from typing import Unpack
else:
    from typing_extensions import Unpack


__all__ = (
    "DescribeProjectVersionsPaginator",
    "DescribeProjectsPaginator",
    "ListCollectionsPaginator",
    "ListDatasetEntriesPaginator",
    "ListDatasetLabelsPaginator",
    "ListFacesPaginator",
    "ListProjectPoliciesPaginator",
    "ListStreamProcessorsPaginator",
    "ListUsersPaginator",
)


_ItemTypeDef = TypeVar("_ItemTypeDef")


class _PageIterator(PageIterator, Generic[_ItemTypeDef]):
    def __iter__(self) -> Iterator[_ItemTypeDef]:
        """
        Proxy method to specify iterator item type.
        """


class DescribeProjectVersionsPaginator(Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/rekognition/paginator/DescribeProjectVersions.html#Rekognition.Paginator.DescribeProjectVersions)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_rekognition/paginators/#describeprojectversionspaginator)
    """

    def paginate(
        self, **kwargs: Unpack[DescribeProjectVersionsRequestDescribeProjectVersionsPaginateTypeDef]
    ) -> _PageIterator[DescribeProjectVersionsResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/rekognition/paginator/DescribeProjectVersions.html#Rekognition.Paginator.DescribeProjectVersions.paginate)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_rekognition/paginators/#describeprojectversionspaginator)
        """


class DescribeProjectsPaginator(Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/rekognition/paginator/DescribeProjects.html#Rekognition.Paginator.DescribeProjects)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_rekognition/paginators/#describeprojectspaginator)
    """

    def paginate(
        self, **kwargs: Unpack[DescribeProjectsRequestDescribeProjectsPaginateTypeDef]
    ) -> _PageIterator[DescribeProjectsResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/rekognition/paginator/DescribeProjects.html#Rekognition.Paginator.DescribeProjects.paginate)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_rekognition/paginators/#describeprojectspaginator)
        """


class ListCollectionsPaginator(Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/rekognition/paginator/ListCollections.html#Rekognition.Paginator.ListCollections)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_rekognition/paginators/#listcollectionspaginator)
    """

    def paginate(
        self, **kwargs: Unpack[ListCollectionsRequestListCollectionsPaginateTypeDef]
    ) -> _PageIterator[ListCollectionsResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/rekognition/paginator/ListCollections.html#Rekognition.Paginator.ListCollections.paginate)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_rekognition/paginators/#listcollectionspaginator)
        """


class ListDatasetEntriesPaginator(Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/rekognition/paginator/ListDatasetEntries.html#Rekognition.Paginator.ListDatasetEntries)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_rekognition/paginators/#listdatasetentriespaginator)
    """

    def paginate(
        self, **kwargs: Unpack[ListDatasetEntriesRequestListDatasetEntriesPaginateTypeDef]
    ) -> _PageIterator[ListDatasetEntriesResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/rekognition/paginator/ListDatasetEntries.html#Rekognition.Paginator.ListDatasetEntries.paginate)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_rekognition/paginators/#listdatasetentriespaginator)
        """


class ListDatasetLabelsPaginator(Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/rekognition/paginator/ListDatasetLabels.html#Rekognition.Paginator.ListDatasetLabels)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_rekognition/paginators/#listdatasetlabelspaginator)
    """

    def paginate(
        self, **kwargs: Unpack[ListDatasetLabelsRequestListDatasetLabelsPaginateTypeDef]
    ) -> _PageIterator[ListDatasetLabelsResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/rekognition/paginator/ListDatasetLabels.html#Rekognition.Paginator.ListDatasetLabels.paginate)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_rekognition/paginators/#listdatasetlabelspaginator)
        """


class ListFacesPaginator(Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/rekognition/paginator/ListFaces.html#Rekognition.Paginator.ListFaces)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_rekognition/paginators/#listfacespaginator)
    """

    def paginate(
        self, **kwargs: Unpack[ListFacesRequestListFacesPaginateTypeDef]
    ) -> _PageIterator[ListFacesResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/rekognition/paginator/ListFaces.html#Rekognition.Paginator.ListFaces.paginate)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_rekognition/paginators/#listfacespaginator)
        """


class ListProjectPoliciesPaginator(Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/rekognition/paginator/ListProjectPolicies.html#Rekognition.Paginator.ListProjectPolicies)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_rekognition/paginators/#listprojectpoliciespaginator)
    """

    def paginate(
        self, **kwargs: Unpack[ListProjectPoliciesRequestListProjectPoliciesPaginateTypeDef]
    ) -> _PageIterator[ListProjectPoliciesResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/rekognition/paginator/ListProjectPolicies.html#Rekognition.Paginator.ListProjectPolicies.paginate)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_rekognition/paginators/#listprojectpoliciespaginator)
        """


class ListStreamProcessorsPaginator(Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/rekognition/paginator/ListStreamProcessors.html#Rekognition.Paginator.ListStreamProcessors)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_rekognition/paginators/#liststreamprocessorspaginator)
    """

    def paginate(
        self, **kwargs: Unpack[ListStreamProcessorsRequestListStreamProcessorsPaginateTypeDef]
    ) -> _PageIterator[ListStreamProcessorsResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/rekognition/paginator/ListStreamProcessors.html#Rekognition.Paginator.ListStreamProcessors.paginate)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_rekognition/paginators/#liststreamprocessorspaginator)
        """


class ListUsersPaginator(Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/rekognition/paginator/ListUsers.html#Rekognition.Paginator.ListUsers)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_rekognition/paginators/#listuserspaginator)
    """

    def paginate(
        self, **kwargs: Unpack[ListUsersRequestListUsersPaginateTypeDef]
    ) -> _PageIterator[ListUsersResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/rekognition/paginator/ListUsers.html#Rekognition.Paginator.ListUsers.paginate)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_rekognition/paginators/#listuserspaginator)
        """

==> types_boto3_full-1.35.91-py3-none-any.whl: types_boto3_rekognition/paginator.py <==
"""
Type annotations for rekognition service client paginators.

[Documentation](https://youtype.github.io/types_boto3_docs/types_boto3_rekognition/paginators/)

Usage::

    ```python
    from boto3.session import Session

    from types_boto3_rekognition.client import RekognitionClient
    from types_boto3_rekognition.paginator import (
        DescribeProjectVersionsPaginator,
        DescribeProjectsPaginator,
        ListCollectionsPaginator,
        ListDatasetEntriesPaginator,
        ListDatasetLabelsPaginator,
        ListFacesPaginator,
        ListProjectPoliciesPaginator,
        ListStreamProcessorsPaginator,
        ListUsersPaginator,
    )

    session = Session()
    client: RekognitionClient = session.client("rekognition")

    describe_project_versions_paginator: DescribeProjectVersionsPaginator = client.get_paginator("describe_project_versions")
    describe_projects_paginator: DescribeProjectsPaginator = client.get_paginator("describe_projects")
    list_collections_paginator: ListCollectionsPaginator = client.get_paginator("list_collections")
    list_dataset_entries_paginator: ListDatasetEntriesPaginator = client.get_paginator("list_dataset_entries")
    list_dataset_labels_paginator: ListDatasetLabelsPaginator = client.get_paginator("list_dataset_labels")
    list_faces_paginator: ListFacesPaginator = client.get_paginator("list_faces")
    list_project_policies_paginator: ListProjectPoliciesPaginator = client.get_paginator("list_project_policies")
    list_stream_processors_paginator: ListStreamProcessorsPaginator = client.get_paginator("list_stream_processors")
    list_users_paginator: ListUsersPaginator = client.get_paginator("list_users")
    ```

Copyright 2025 Vlad Emelianov
"""

from __future__ import annotations

import sys
from typing import TYPE_CHECKING

from botocore.paginate import PageIterator, Paginator

from .type_defs import (
    DescribeProjectsRequestPaginateTypeDef,
    DescribeProjectsResponseTypeDef,
    DescribeProjectVersionsRequestPaginateTypeDef,
    DescribeProjectVersionsResponseTypeDef,
    ListCollectionsRequestPaginateTypeDef,
    ListCollectionsResponseTypeDef,
    ListDatasetEntriesRequestPaginateTypeDef,
    ListDatasetEntriesResponseTypeDef,
    ListDatasetLabelsRequestPaginateTypeDef,
    ListDatasetLabelsResponseTypeDef,
    ListFacesRequestPaginateTypeDef,
    ListFacesResponseTypeDef,
    ListProjectPoliciesRequestPaginateTypeDef,
    ListProjectPoliciesResponseTypeDef,
    ListStreamProcessorsRequestPaginateTypeDef,
    ListStreamProcessorsResponseTypeDef,
    ListUsersRequestPaginateTypeDef,
    ListUsersResponseTypeDef,
)

if sys.version_info >= (3, 12):
    from typing import Unpack
else:
    from typing_extensions import Unpack


__all__ = (
    "DescribeProjectVersionsPaginator",
    "DescribeProjectsPaginator",
    "ListCollectionsPaginator",
    "ListDatasetEntriesPaginator",
    "ListDatasetLabelsPaginator",
    "ListFacesPaginator",
    "ListProjectPoliciesPaginator",
    "ListStreamProcessorsPaginator",
    "ListUsersPaginator",
)


if TYPE_CHECKING:
    _DescribeProjectVersionsPaginatorBase = Paginator[DescribeProjectVersionsResponseTypeDef]
else:
    _DescribeProjectVersionsPaginatorBase = Paginator  # type: ignore[assignment]


class DescribeProjectVersionsPaginator(_DescribeProjectVersionsPaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/rekognition/paginator/DescribeProjectVersions.html#Rekognition.Paginator.DescribeProjectVersions)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_rekognition/paginators/#describeprojectversionspaginator)
    """

    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[DescribeProjectVersionsRequestPaginateTypeDef]
    ) -> PageIterator[DescribeProjectVersionsResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/rekognition/paginator/DescribeProjectVersions.html#Rekognition.Paginator.DescribeProjectVersions.paginate)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_rekognition/paginators/#describeprojectversionspaginator)
        """


if TYPE_CHECKING:
    _DescribeProjectsPaginatorBase = Paginator[DescribeProjectsResponseTypeDef]
else:
    _DescribeProjectsPaginatorBase = Paginator  # type: ignore[assignment]


class DescribeProjectsPaginator(_DescribeProjectsPaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/rekognition/paginator/DescribeProjects.html#Rekognition.Paginator.DescribeProjects)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_rekognition/paginators/#describeprojectspaginator)
    """

    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[DescribeProjectsRequestPaginateTypeDef]
    ) -> PageIterator[DescribeProjectsResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/rekognition/paginator/DescribeProjects.html#Rekognition.Paginator.DescribeProjects.paginate)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_rekognition/paginators/#describeprojectspaginator)
        """


if TYPE_CHECKING:
    _ListCollectionsPaginatorBase = Paginator[ListCollectionsResponseTypeDef]
else:
    _ListCollectionsPaginatorBase = Paginator  # type: ignore[assignment]


class ListCollectionsPaginator(_ListCollectionsPaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/rekognition/paginator/ListCollections.html#Rekognition.Paginator.ListCollections)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_rekognition/paginators/#listcollectionspaginator)
    """

    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[ListCollectionsRequestPaginateTypeDef]
    ) -> PageIterator[ListCollectionsResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/rekognition/paginator/ListCollections.html#Rekognition.Paginator.ListCollections.paginate)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_rekognition/paginators/#listcollectionspaginator)
        """


if TYPE_CHECKING:
    _ListDatasetEntriesPaginatorBase = Paginator[ListDatasetEntriesResponseTypeDef]
else:
    _ListDatasetEntriesPaginatorBase = Paginator  # type: ignore[assignment]


class ListDatasetEntriesPaginator(_ListDatasetEntriesPaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/rekognition/paginator/ListDatasetEntries.html#Rekognition.Paginator.ListDatasetEntries)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_rekognition/paginators/#listdatasetentriespaginator)
    """

    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[ListDatasetEntriesRequestPaginateTypeDef]
    ) -> PageIterator[ListDatasetEntriesResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/rekognition/paginator/ListDatasetEntries.html#Rekognition.Paginator.ListDatasetEntries.paginate)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_rekognition/paginators/#listdatasetentriespaginator)
        """


if TYPE_CHECKING:
    _ListDatasetLabelsPaginatorBase = Paginator[ListDatasetLabelsResponseTypeDef]
else:
    _ListDatasetLabelsPaginatorBase = Paginator  # type: ignore[assignment]


class ListDatasetLabelsPaginator(_ListDatasetLabelsPaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/rekognition/paginator/ListDatasetLabels.html#Rekognition.Paginator.ListDatasetLabels)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_rekognition/paginators/#listdatasetlabelspaginator)
    """

    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[ListDatasetLabelsRequestPaginateTypeDef]
    ) -> PageIterator[ListDatasetLabelsResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/rekognition/paginator/ListDatasetLabels.html#Rekognition.Paginator.ListDatasetLabels.paginate)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_rekognition/paginators/#listdatasetlabelspaginator)
        """


if TYPE_CHECKING:
    _ListFacesPaginatorBase = Paginator[ListFacesResponseTypeDef]
else:
    _ListFacesPaginatorBase = Paginator  # type: ignore[assignment]


class ListFacesPaginator(_ListFacesPaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/rekognition/paginator/ListFaces.html#Rekognition.Paginator.ListFaces)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_rekognition/paginators/#listfacespaginator)
    """

    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[ListFacesRequestPaginateTypeDef]
    ) -> PageIterator[ListFacesResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/rekognition/paginator/ListFaces.html#Rekognition.Paginator.ListFaces.paginate)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_rekognition/paginators/#listfacespaginator)
        """


if TYPE_CHECKING:
    _ListProjectPoliciesPaginatorBase = Paginator[ListProjectPoliciesResponseTypeDef]
else:
    _ListProjectPoliciesPaginatorBase = Paginator  # type: ignore[assignment]


class ListProjectPoliciesPaginator(_ListProjectPoliciesPaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/rekognition/paginator/ListProjectPolicies.html#Rekognition.Paginator.ListProjectPolicies)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_rekognition/paginators/#listprojectpoliciespaginator)
    """

    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[ListProjectPoliciesRequestPaginateTypeDef]
    ) -> PageIterator[ListProjectPoliciesResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/rekognition/paginator/ListProjectPolicies.html#Rekognition.Paginator.ListProjectPolicies.paginate)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_rekognition/paginators/#listprojectpoliciespaginator)
        """


if TYPE_CHECKING:
    _ListStreamProcessorsPaginatorBase = Paginator[ListStreamProcessorsResponseTypeDef]
else:
    _ListStreamProcessorsPaginatorBase = Paginator  # type: ignore[assignment]


class ListStreamProcessorsPaginator(_ListStreamProcessorsPaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/rekognition/paginator/ListStreamProcessors.html#Rekognition.Paginator.ListStreamProcessors)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_rekognition/paginators/#liststreamprocessorspaginator)
    """

    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[ListStreamProcessorsRequestPaginateTypeDef]
    ) -> PageIterator[ListStreamProcessorsResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/rekognition/paginator/ListStreamProcessors.html#Rekognition.Paginator.ListStreamProcessors.paginate)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_rekognition/paginators/#liststreamprocessorspaginator)
        """


if TYPE_CHECKING:
    _ListUsersPaginatorBase = Paginator[ListUsersResponseTypeDef]
else:
    _ListUsersPaginatorBase = Paginator  # type: ignore[assignment]


class ListUsersPaginator(_ListUsersPaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/rekognition/paginator/ListUsers.html#Rekognition.Paginator.ListUsers)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_rekognition/paginators/#listuserspaginator)
    """

    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[ListUsersRequestPaginateTypeDef]
    ) -> PageIterator[ListUsersResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/rekognition/paginator/ListUsers.html#Rekognition.Paginator.ListUsers.paginate)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_rekognition/paginators/#listuserspaginator)
        """
